@@ -26,7 +26,8 @@ APIS = {
     'facebook':'FACEBOOK',
     'trends':'GOOGLE_TRENDS',
     'news_polish':'INTERIA',
-    'concerts':'SONGKICK'
+    'concerts':'SONGKICK',
+    'nu': 'NU'
 }
 
 VIDEO_EXTENSIONS = [ext for ext in mimetypes.types_map if mimetypes.types_map[ext].split('/')[0] == 'video']
